@@ -61,6 +61,7 @@ setRefClass("H2OConnectionMutableState",
 #' @slot password Password to login with.
 #' @slot cluster_id Cluster to login to. Used for Steam connections
 #' @slot cookies Cookies to add to request
+#' @slot context_path Context path which is appended to H2O server location.
 #' @slot mutable An \code{H2OConnectionMutableState} object to hold the mutable state for the H2O connection.
 #' @aliases H2OConnection
 #' @export
@@ -70,6 +71,7 @@ setClass("H2OConnection",
                         username="character", password="character",
                         cluster_id="numeric",
                         cookies="character",
+                        context_path="character",
                         mutable="H2OConnectionMutableState"),
          prototype(ip           = NA_character_,
                    port         = NA_integer_,
@@ -80,6 +82,7 @@ setClass("H2OConnection",
                    password     = NA_character_,
                    cluster_id   = NA_integer_,
                    cookies      = NA_character_,
+                   context_path = NA_character_,
                    mutable      = new("H2OConnectionMutableState")))
 
 setClassUnion("H2OConnectionOrNULL", c("H2OConnection", "NULL"))
@@ -279,6 +282,9 @@ setClass("H2OAutoEncoderModel", contains="H2OModel")
 #' @rdname H2OModel-class
 #' @export
 setClass("H2ODimReductionModel", contains="H2OModel")
+#' @rdname H2OModel-class
+#' @export
+setClass("H2OWordEmbeddingModel", contains="H2OModel")
 
 #'
 #' Accessor Methods for H2OModel Object
@@ -397,7 +403,7 @@ setMethod("show", "H2OBinomialMetrics", function(object) {
     cm <- h2o.confusionMatrix(object)
     if( is.null(cm) ) print(NULL)
     else {
-      attr(cm, "header") <- "Confusion Matrix for F1-optimal threshold"
+      attr(cm, "header") <- "Confusion Matrix (vertical: actual; across: predicted) for F1-optimal threshold"
       print(cm)
       cat("\n")
     }
@@ -508,6 +514,10 @@ setMethod("show", "H2ODimReductionMetrics", function(object) {
   } else print(NULL)
 })
 
+#' @rdname H2OModelMetrics-class
+#' @export
+setClass("H2OWordEmbeddingMetrics", contains="H2OModelMetrics")
+
 #' H2O Future Model
 #'
 #' A class to contain the information for background model jobs.
